@@ -18,6 +18,7 @@ var freeTestsGenerators = map[string]TestsGenerator{ // by subdirectory.
 	"base-test":                       BaseTestsGenerator{},
 	"error-as-target":                 ErrorAsTargetTestsGenerator{},
 	"expected-var-custom-pattern":     ExpectedVarCustomPatternTestsGenerator{},
+	"formatter-not-defaults":          FormatterNotDefaultsTestsGenerator{},
 	"require-error-fn-pattern":        RequireErrorFnPatternTestsGenerator{},
 	"suite-require-extra-assert-call": SuiteRequireExtraAssertCallTestsGenerator{},
 }
@@ -26,18 +27,24 @@ var checkerTestsGenerators = []CheckerTestsGenerator{
 	BlankImportTestsGenerator{},
 	BoolCompareTestsGenerator{},
 	ComparesTestsGenerator{},
+	ContainsTestsGenerator{},
 	EmptyTestsGenerator{},
+	EncodedCompareTestsGenerator{},
 	ErrorNilTestsGenerator{},
 	ErrorIsAsTestsGenerator{},
 	ExpectedActualTestsGenerator{},
 	FloatCompareTestsGenerator{},
+	FormatterTestsGenerator{},
 	GoRequireTestsGenerator{},
 	LenTestsGenerator{},
 	NegativePositiveTestsGenerator{},
 	NilCompareTestsGenerator{},
+	RegexpTestsGenerator{},
 	RequireErrorTestsGenerator{},
-	SuiteDontUsePkg{},
+	SuiteBrokenParallelTestsGenerator{},
+	SuiteDontUsePkgTestsGenerator{},
 	SuiteExtraAssertCallTestsGenerator{},
+	SuiteSubtestRunTestsGenerator{},
 	SuiteTHelperTestsGenerator{},
 	UselessAssertTestsGenerator{},
 }
