@@ -1,10 +1,11 @@
 package main
 
 import (
-	"github.com/Crocmagnon/fatcontext/pkg/analyzer"
 	"golang.org/x/tools/go/analysis/singlechecker"
+
+	"github.com/Crocmagnon/fatcontext/pkg/analyzer"
 )
 
 func main() {
-	singlechecker.Main(analyzer.Analyzer)
+	singlechecker.Main(analyzer.NewAnalyzer())
 }
