@@ -12,4 +12,7 @@ func tests() {
 	slog.Info("msg", "foo", 1, "bar", 2)                // want `key-value pairs should not be used`
 	slog.Info("msg", "foo", 1, slog.Int("bar", 2))      // want `key-value pairs should not be used`
 	slog.With("foo", 1, slog.Int("bar", 2)).Info("msg") // want `key-value pairs should not be used`
+
+	args := []slog.Attr{slog.Int("foo", 1), slog.Int("bar", 2)}
+	slog.LogAttrs(nil, slog.LevelInfo, "msg", args...)
 }
